import Head from 'next/head';
import React from 'react';
import { GetServerSideProps } from 'next';
import { apiClientGet } from '@/lib/apiClient';
import { ApolloQueryResult, gql } from '@apollo/client';
import Link from 'next/link';
import { GameLightFragment, GameLight } from '@/lib/game';
import { extendFragment, includeFragment } from '@/lib/fragment';

type PageData = {
  game:GameLight;
}

type PageProps = ApolloQueryResult<PageData>

export const getServerSideProps:GetServerSideProps<PageProps> = async () => {
  const client = await apiClientGet();

  const res = await client.query<PageData>({
    query: gql`
      ${includeFragment(GameLightFragment)}

      query getGame($id: ID!) {
        game(id: $id) {
          ${extendFragment(GameLightFragment)}
        }
      }
    `,
    variables: {
      id: '0'
    }
  });

  return {
    props: res
  };
};

const HomePage: React.FC<PageProps> = props => {
  return (
    <div className="homepage">
      <Head>
        <title>HomePlay, your personal video game library</title>
      </Head>

      <Link href="/games">
        Games
      </Link>
      { JSON.stringify(props) }
    </div>
  );
}

export default HomePage;